/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <iostream>
#include <gtkmm.h>

#include <string>

#include "../config.h"

#include "application.h"
#include "window.h"
#include "fileloader.h"
#include "drawingarea.h"

Application::Application() :
  Gtk::Application("pl.net.dlugolecki.familia",
		   Gio::APPLICATION_FLAGS_NONE)
{
  Glib::set_application_name(PACKAGE_STRING);

  FileLoader::instance()->signal_open().connect(sigc::mem_fun(*this, &Application::on_open_file));
  FileLoader::instance()->signal_close().connect(sigc::mem_fun(*this, &Application::on_close_file));
}

Glib::RefPtr<Application> Application::create()
{
  return Glib::RefPtr<Application> (new Application());
}

void Application::setup() {
  m_refBuilder = Gtk::Builder::create();

  m_refBuilder->add_from_file(get_datadir_path_to("familia.glade"));

  Window * window = NULL;
  m_refBuilder->get_widget_derived("flwindow", window);
  add_window(*window);
  window->show();

  Gtk::Notebook * notebook = NULL;
  m_refBuilder->get_widget("flnotebook", notebook);
  //  notebook->signal_page_removed().connect(sigc::mem_fun(*this, &Application::on_close_file));

}

void Application::on_activate()
{
  setup();
}

void Application::on_open_file(file::File * file, const guint index)
{
  Gtk::Notebook * notebook = NULL;
  m_refBuilder->get_widget("flnotebook", notebook);

  //  std::cout << "Boundary position: \n" << file->views[0].boundary().get_x() << "\n" << file->views[0].boundary().get_y() << "\n" << std::endl;
  std::cout << "Boundary size: \n" << file->views[0].boundary().get_width() << "\n" << file->views[0].boundary().get_height() << "\n" << std::endl;
  //  std::cout << "Position: \n" << file->views[0].position().get_x() << "\n" << file->views[0].position().get_y() << "\n" << std::endl;
  /*
  Glib::RefPtr<Gtk::Adjustment> hadjustment = Gtk::Adjustment::create(100, 0, 1000);
  Glib::RefPtr<Gtk::Adjustment> vadjustment = Gtk::Adjustment::create(100, 0, 1000);

  */
  Gtk::ScrolledWindow * page = Gtk::manage(new Gtk::ScrolledWindow);
  DrawingArea * drawing = Gtk::manage(new DrawingArea);

  drawing->index = index;
  drawing->set_size_request(file->views[0].boundary().get_width(), -file->views[0].boundary().get_height());
  page->add(*drawing);

  Gtk::Label label(file->details.name);
  notebook->insert_page(*page, label, index);
  notebook->show_all_children();
}

void Application::on_close_file(file::File * file, const guint index)
{
  //  FileLoader::instance()->signal_close().emit(file, index);
  //  notebook->remove_page(index);
}

Glib::ustring Application::get_datadir_path_to(Glib::ustring name)
{
  //Add tests for current method, just in case of upgrading this 
  //method in future
  std::string filename = Glib::build_filename("data", name);
  
  if(Glib::file_test(filename, Glib::FILE_TEST_EXISTS) == FALSE) {

    filename = Glib::build_filename(DATADIR, PACKAGE_TARNAME, name);

    if(Glib::file_test(filename, Glib::FILE_TEST_EXISTS) == FALSE) {
      std::cerr << "[Error] File " << name << " not found.\n";
      throw;
    }
  }
  return filename;
}
