/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <iostream>
#include <gtkmm.h>
#include <cairomm/cairomm.h>

#include "individual.h"

namespace file {

Individual::Individual() {
}

Individual::~Individual() {
  _viewId.clear();
}

Individual::_Name& Individual::name() {
  return _name;
}

Individual::_Position& Individual::position() {
  return _position;
}

Individual::_Boundary& Individual::boundary() {
  return _boundary;
}

Individual::String& Individual::viewId() {
  return _viewId;
}

bool Individual::isDead() {
  return _deceased;
}

gender_type Individual::getGender() {
  return _gender;
}

Individual& Individual::setDead(bool value) {
  _deceased = value;
  return (*this);
}

Individual& Individual::setGender(gender_type type) {
  _gender = type;
  return (*this);
}
/*
void Individual::draw(const Cairo::RefPtr<Cairo::Context>& cr) {
  switch(_gender) {
  case male:
    break;
  case female:
    break;
  }
*/
void Individual::draw(const Cairo::RefPtr<Cairo::Context>& cr) {
  cr->save();

  //Draw bounding box
  cr->rectangle(boundary().get_x(),
		boundary().get_y(),
		boundary().get_width(),
		boundary().get_height());

  // draw a little dot at the point where text will be drawn
  cr->arc(position().get_x(), position().get_y(), 5.0, 0, 2*M_PI);
  cr->set_source_rgba(0.0, 1.0, 0.0, 0.2);
  cr->fill();
  
  // draw the text
  //  cairo_move_to(cr.gobj(), position.get_x(), position.get_y());
  //  cr->move_to(position.get_x(), position.get_y());
  Cairo::RefPtr<Cairo::ToyFontFace> font =
    Cairo::ToyFontFace::create("Liberation Serif",
                               Cairo::FONT_SLANT_ITALIC,
                               Cairo::FONT_WEIGHT_BOLD);
  cr->set_source_rgb(0, 0, 0);
  cr->set_font_face(font);
  cr->set_font_size(15);
  cr->translate(position().get_x(), position().get_y());
  std::cout << name().getFirst() + " " + name().getLast() << std::endl;
  std::cout << "Pos: " << position().get_x() << ", " << position().get_y() << std::endl;
  cr->show_text(name().getFirst() + " " + name().getLast());

  cr->restore();
}

}
