/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <gtkmm.h>
#include <iostream>

#include "fileloader.h"

#include "file/file.h"
#include "file/gno/gno.h"

namespace file {

Loader::Loader()
{
  signal_open().connect(sigc::mem_fun(*this, &file::Loader::on_open));
  signal_close().connect(sigc::mem_fun(*this, &file::Loader::on_close));
}
void Loader::open(const Glib::ustring filepath)
{
  std::cout << "Opening file " << filepath << std::endl;
  File * file = new File(filepath);

  if(file->details.extension == "gno") {
    Gno gno(file);
    files.push_back(file);
  }
  
  signal_open().emit(file, files.size()-1);

  //  if(file)
  //    tabs.append_page(*file, filename);

  //  tabs.show_all();  
}

void Loader::close(const int index)
{  
  if(index < files.size()) {
    signal_close().emit(files.at(index), index);
    delete files.at(index);
  }
}

Loader::signal_type Loader::signal_open()
{
  return m_signal_open;
}

Loader::signal_type Loader::signal_close()
{
  return m_signal_close;
}

//Default handler for file open event
void Loader::on_open(File *file, const guint index)
{
  std::cout << "Default handler. After opening of '" <<
    file->details.name << "' file." << std::endl;
}

//Default handler for file close event
void Loader::on_close(File *file, const guint index)
{
  std::cout << "Default handler. Before closing of '" <<
    file->details.name << "' file." << std::endl;
}

};
