/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILELOADER_H
#define _FILELOADER_H

#include <iostream>
#include <vector>
#include "singleton.h"
#include "file/file.h"

namespace file {

class Loader {
public:
  typedef Glib::ustring String;

public:
  Loader();
  void open(const Glib::ustring filepath);
  void close(const int index);

  /* Signal type */
  typedef sigc::signal<void, File *, const guint> signal_type;
  /* Signal wrapper */
  signal_type signal_open();
  signal_type signal_close();


  std::vector<File *> files;
protected:
  /* Signals */
  signal_type m_signal_open;
  signal_type m_signal_close;

  /* Default signal handler for file operations */
  virtual void on_open(File *file, const guint index);
  virtual void on_close(File *file, const guint index);
};

};

typedef singleton<file::Loader> FileLoader;

#endif
