/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <iostream>
#include <gtkmm.h>
#include <glibmm/i18n.h>
//#include <sigc++/sigc++.h>

#include "../config.h"
#include "singleton.h"
#include "application.h"
#include "window.h"
#include "fileloader.h"


Window::Window(BaseObjectType* cobject, const
	       Glib::RefPtr<Gtk::Builder>& builder)
  : Gtk::ApplicationWindow(cobject), m_refBuilder(builder) {

  //Load menu from file
  m_refUIManager = Gtk::UIManager::create();
  m_refUIManager->add_ui_from_file(Application::get_datadir_path_to("familia.ui"));

  //Connect actions with menu items
  m_refActionGroup =
  Glib::RefPtr<Gtk::ActionGroup>::cast_dynamic(m_refBuilder->get_object("FileActions"));
  m_refActionGroup->get_action("FileOpen")->signal_activate().connect(sigc::mem_fun(*this, &Window::on_menu_file_open));
  m_refActionGroup->get_action("FileQuit")->signal_activate().connect(sigc::mem_fun(*this, &Window::on_menu_file_close));

  m_refUIManager->insert_action_group(m_refActionGroup);
  add_accel_group(m_refUIManager->get_accel_group());

  //Add menu to window
  Gtk::Box * box;
  m_refBuilder->get_widget("box1", box);
  box->pack_end(*m_refUIManager->get_widget("/MenuBar"), Gtk::PACK_SHRINK);
}

Window::~Window() {
}

void Window::on_menu_file_open() {
  Gtk::FileChooserDialog * dialog = 0;
  m_refBuilder->get_widget("filechooserdialog", dialog);

  if(!dialog) {
    std::cerr << "No dialog loaded\n";
    return;
  }  
  dialog->set_transient_for(*this);

  Glib::RefPtr<Gtk::FileFilter> filter_gno = Gtk::FileFilter::create();
  filter_gno->set_name(_("Gno Files"));
  filter_gno->add_pattern("*.gno");
  dialog->add_filter(filter_gno);

  Glib::RefPtr<Gtk::FileFilter> filter_any = Gtk::FileFilter::create();
  filter_any->set_name(_("Any files"));
  filter_any->add_pattern("*");
  dialog->add_filter(filter_any);


  //Show the dialog and wait for a user response:
  int result = dialog->run();

  //Handle the response:
  switch(result) {
    case(Gtk::RESPONSE_OK):
      {
	std::cout << "OK clicked." << std::endl;
	FileLoader::instance()->open(dialog->get_filename());

	//	Glib::RefPtr<Application>::cast_dynamic(get_application())->open_file(dialog->get_filename());
	break;
      }
    case(Gtk::RESPONSE_CANCEL):
    case(Gtk::RESPONSE_DELETE_EVENT):
      {
	break;
      }
    default:
      {
	std::cerr << "Unexpected button clicked in opendialog. Code: "
		  << result << std::endl;
	break;
      }
    }
  dialog->hide();
}

void Window::on_menu_file_close() {
  hide();
}
